@@ -1,4 +1,4 @@
-__version__ = "6.2.26"
+__version__ = "6.2.27"
 
 from zuper_commons.logs import ZLogger
 
@@ -11,3 +11,7 @@ logger.debug(f"dt-protocols version {__version__} path {path}")
 from .basics import *
 from .collision_drawing import *
 from .collision_protocol import *
+from .statistics import *
+from .utils import *
+from .visualization import *
+from .checker import *
